@@ -1,4 +1,4 @@
-#!/usr/bin/python3.13
+#!/usr/bin/python3.11
 
 # SPDX-License-Identifier: GPL-3.0-or-later
 # SPDX-FileCopyrightText: 2010  Darwin M. Bautista <djclue917@gmail.com>
@@ -14,6 +14,7 @@ import gettext
 
 import getopt
 import shutil
+import subprocess
 import hashlib
 import io
 
@@ -305,8 +306,10 @@ def getStatus(ufw, xmlStr):
 def setEnabled(ufw, status):
     if status.lower() == "false":
         stat=False
+        os.system('systemctl disable ufw')
     else:
         stat=True
+        os.system('systemctl enable ufw')
     if stat != ufw.backend._is_enabled():
         ufw.set_enabled(stat)
         if ufw.backend._is_enabled() != stat:
